
## CATO-CLI - query.eventsFeed:
[Click here](https://api.catonetworks.com/documentation/#query-eventsFeed) for documentation on this operation.

### Usage for query.eventsFeed:

`catocli query eventsFeed -h`

`catocli query eventsFeed <accountID> <json>`

`catocli query eventsFeed 12345 "$(cat < eventsFeed.json)"`

`catocli query eventsFeed 12345 '{"EventFeedFieldFilterInput": {"fieldName": {"fieldName": "enum(EventFeedFilterFieldName)"}, "operator": {"operator": "enum(EventFeedFilterOperator)"}, "values": {"values": ["String"]}}, "accountIDs": ["ID"], "fieldNames": "enum(EventFieldName)", "marker": "String"}'`

#### Operation Arguments for query.eventsFeed ####
`EventFeedFieldFilterInput` [EventFeedFieldFilterInput[]] - (optional) N/A 
`accountIDs` [ID[]] - (optional) List of Unique Account Identifiers. 
`fieldNames` [EventFieldName[]] - (optional) N/A Default Value: ['src_site', 'src_site_id', 'static_host', 'user_id', 'dest_site', 'dest_site_id', 'src_or_dest_site_id', 'rule', 'ISP_name', 'socket_interface', 'custom_category', 'directory_host_name', 'dest_port', 'bgp_peer_asn', 'user_reference_id', 'src_port', 'link_health_pkt_loss', 'pop_name', 'host_ip', 'event_message', 'src_site_name', 'domain_name', 'dest_ip', 'file_hash', 'src_isp_ip', 'authentication_type', 'rule_name', 'directory_sync_result', 'host_mac', 'threat_type', 'threat_verdict', 'device_name', 'link_type', 'login_type', 'configured_host_name', 'internalId', 'directory_sync_type', 'vpn_user_email', 'client_class', 'incident_aggregation', 'socket_reset', 'user_name', 'client_version', 'file_size', 'registration_code', 'bgp_error_code', 'bgp_peer_description', 'threat_name', 'qos_reported_time', 'ip_protocol', 'bgp_cato_asn', 'src_ip', 'threat_reference', 'action', 'windows_domain_name', 'risk_level', 'socket_old_version', 'link_health_latency', 'tunnel_protocol', 'socket_new_version', 'socket_version', 'link_health_jitter', 'upgrade_start_time', 'bgp_cato_ip', 'categories', 'rule_id', 'socket_role', 'targets_cardinality', 'upgrade_initiated_by', 'dest_is_site_or_vpn', 'bgp_peer_ip', 'src_is_site_or_vpn', 'ad_name', 'user_awareness_method', 'link_health_is_congested', 'subnet_name', 'os_version', 'event_sub_type', 'os_type', 'traffic_direction', 'bgp_suberror_code', 'bgp_route_cidr', 'incident_id', 'application', 'application_name', 'application_id', 'upgrade_end_time', 'socket_interface_id', 'custom_categories', 'custom_category_id', 'custom_category_name', 'src_country', 'src_country_code', 'event_count', 'file_name', 'directory_ip', 'time', 'url', 'dest_country', 'dest_country_code', 'flows_cardinality', 'dest_site_name', 'event_type', 'account_id', 'signature_id', 'client_cert_expires', 'client_cert_name', 'is_sanctioned_app', 'app_activity', 'app_activity_type', 'device_posture_profile', 'device_posture_profiles', 'full_path_url', 'application_risk', 'mitre_attack_techniques', 'mitre_attack_subtechniques', 'mitre_attack_tactics', 'indicator', 'connector_type', 'connector_name', 'connector_status', 'parent_connector_name', 'file_type', 'dlp_fail_mode', 'dlp_profiles', 'matched_data_types', 'severity', 'owner', 'collaborators', 'email_subject', 'sharing_scope', 'dns_protection_category', 'final_object_status', 'object_name', 'object_type', 'object_id', 'alert_id', 'vendor', 'vendor_user_id', 'status', 'classification', 'quarantine_folder_path', 'title', 'recommended_actions', 'pid', 'parent_pid', 'process_path', 'failure_reason', 'out_of_band_access', 'logged_in_user', 'http_request_method', 'xff', 'dns_query', 'key_name', 'api_type', 'api_name', 'app_stack', 'tls_rule_name', 'tls_certificate_error', 'tls_version', 'tls_error_type', 'tls_error_description', 'cato_app', 'prompt_action', 'device_id', 'visible_device_id', 'auth_method', 'bypass_method', 'bypass_duration_sec', 'bypass_reason', 'sign_in_event_types', 'tenant_id', 'tenant_name', 'user_agent', 'vendor_event_id', 'vendor_device_id', 'vendor_device_name', 'is_compliant', 'is_managed', 'trust_type', 'confidence_level', 'dlp_scan_types', 'network_access', 'analyst_verdict', 'criticality', 'indication', 'producer', 'story_id', 'raw_data', 'trigger', 'network_rule', 'congestion_algorithm', 'tcp_acceleration', 'tls_inspection', 'public_ip', 'egress_site_name', 'egress_pop_name', 'qos_priority', 'split_tunnel_configuration', 'pac_file', 'always_on_configuration', 'vpn_lan_access', 'connect_on_boot', 'trusted_networks', 'office_mode', 'device_certificate', 'tunnel_ip_protocol', 'notification_description', 'notification_api_error', 'reference_url', 'app_activity_category', 'is_admin_activity', 'is_admin', 'collaborator_name', 'dest_group_id', 'dest_group_name', 'access_method', 'vendor_collaborator_id']
`marker` [String] - (optional) Marker to use to get results from 
